@@ -6,9 +6,8 @@ sub Webqq::Client::_send_discuss_message {
     return if $self->{type} ne 'smartqq';
     my $msg = shift;
     my $ua = $self->{asyn_ua};
-    my $api_url = 'http://d.web2.qq.com/channel/send_discu_msg2';
+    my $api_url = ($self->{is_https}?'https':'http') . '://d.web2.qq.com/channel/send_discu_msg2';
 
-    my $send_message_callback = $msg->{cb} || $self->{on_send_message};
     my $callback = sub{
         my $response = shift;   
         print $response->content(),"\n" if $self->{debug};
@@ -17,12 +16,21 @@ sub Webqq::Client::_send_discuss_message {
             $self->send_discuss_message($msg);
             return;
         }
-        elsif(defined $status and ref $send_message_callback eq 'CODE'){
-            $send_message_callback->(
-                $msg,                   #msg
-                $status->{is_success},  #is_success
-                $status->{status}       #status
-            );
+        elsif(defined $status){
+            if(ref $msg->{cb} eq 'CODE'){
+                $msg->{cb}->(
+                    $msg,                   #msg
+                    $status->{is_success},  #is_success
+                    $status->{status}       #status
+                );
+            }
+            if(ref $self->{on_send_message} eq 'CODE'){
+                $self->{on_send_message}->(
+                    $msg,                   #msg
+                    $status->{is_success},  #is_success
+                    $status->{status}       #status
+                );
+            }
         }
     };
 
